@@ -17,7 +17,7 @@
 %                               September 2002                                %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2019 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -272,8 +272,14 @@ MagickExport const char *GetMagickFeatures(void)
   " "
 #endif
 #endif
+#if defined(MAGICKCORE_HAVE_TCMALLOC)
+  "TCMalloc "
+#endif
 #if defined(ZERO_CONFIGURATION_SUPPORT)
   "Zero-configuration "
+#endif
+#if (MAGICKCORE_QUANTUM_DEPTH == 64)
+  "Q64 (experimental, not for production) "
 #endif
   ;
 }
@@ -552,7 +558,7 @@ MagickExport unsigned int GetMagickCoreSignature(const StringInfo *nonce)
   signature=MagickLibInterface;
   (void) memcpy(p,&signature,sizeof(signature));
   p+=sizeof(signature);
-  signature=1;  /* endianess */
+  signature=1;  /* endinaness */
   (void) memcpy(p,&signature,sizeof(signature));
   p+=sizeof(signature);
   SetStringInfoLength(version,p-GetStringInfoDatum(version));
